@@ -5,6 +5,8 @@ from typing import TYPE_CHECKING, Hashable, Iterable, Sequence
 import numpy as np
 import pandas as pd
 import xarray as xr
+from packaging.version import Version
+from xarray.core.duck_array_ops import _datetime_nanmin
 
 from .aggregations import Aggregation, _atleast_1d
 from .core import (
@@ -14,6 +16,7 @@ from .core import (
     rechunk_for_blockwise as rechunk_array_for_blockwise,
     rechunk_for_cohorts as rechunk_array_for_cohorts,
 )
+from .xrutils import _contains_cftime_datetimes, _to_pytimedelta, datetime_to_numeric
 
 if TYPE_CHECKING:
     from xarray import DataArray, Dataset, Resample
@@ -288,7 +291,27 @@ def xarray_reduce(
             if "nan" not in func and func not in ["all", "any", "count"]:
                 func = f"nan{func}"
 
+        requires_numeric = func not in ["count", "any", "all"]
+        if requires_numeric:
+            is_npdatetime = array.dtype.kind in "Mm"
+            is_cftime = _contains_cftime_datetimes(array)
+            if is_npdatetime:
+                offset = _datetime_nanmin(array)
+                # xarray always uses np.datetime64[ns] for np.datetime64 data
+                dtype = "timedelta64[ns]"
+                array = datetime_to_numeric(array, offset)
+            elif _contains_cftime_datetimes(array):
+                offset = min(array)
+                array = datetime_to_numeric(array, offset, datetime_unit="us")
+
         result, *groups = groupby_reduce(array, *by, func=func, **kwargs)
+
+        if requires_numeric:
+            if is_npdatetime:
+                return result.astype(dtype) + offset
+            elif is_cftime:
+                return _to_pytimedelta(result, unit="us") + offset
+
         return result
 
     # These data variables do not have any of the core dimension,
@@ -345,12 +368,16 @@ def xarray_reduce(
             expect = expect.to_numpy()
         if isinstance(actual, xr.Dataset) and name in actual:
             actual = actual.drop_vars(name)
-        actual[name] = expect
-
-    # if grouping by multi-indexed variable, then restore it
-    for name, index in ds.indexes.items():
-        if name in actual.indexes and isinstance(index, pd.MultiIndex):
-            actual[name] = index
+        # When grouping by MultiIndex, expect is an pd.Index wrapping
+        # an object array of tuples
+        if name in ds.indexes and isinstance(ds.indexes[name], pd.MultiIndex):
+            levelnames = ds.indexes[name].names
+            expect = pd.MultiIndex.from_tuples(expect.values, names=levelnames)
+            actual[name] = expect
+            if Version(xr.__version__) > Version("2022.03.0"):
+                actual = actual.set_coords(levelnames)
+        else:
+            actual[name] = expect
 
     if unindexed_dims:
         actual = actual.drop_vars(unindexed_dims)
@@ -361,7 +388,8 @@ def xarray_reduce(
                 template = obj
             else:
                 template = obj[var]
-            actual[var] = _restore_dim_order(actual[var], template, by[0])
+            if actual[var].ndim > 1:
+                actual[var] = _restore_dim_order(actual[var], template, by[0])
 
     if missing_dim:
         for k, v in missing_dim.items():
@@ -370,9 +398,9 @@ def xarray_reduce(
             }
             # The expand_dims is for backward compat with xarray's questionable behaviour
             if missing_group_dims:
-                actual[k] = v.expand_dims(missing_group_dims)
+                actual[k] = v.expand_dims(missing_group_dims).variable
             else:
-                actual[k] = v
+                actual[k] = v.variable
 
     if isinstance(obj, xr.DataArray):
         return obj._from_temp_dataset(actual)
