@@ -321,6 +321,17 @@ def test_multi_index_groupby_sum(engine):
     actual = xarray_reduce(stacked, "space", dim="z", func="sum", engine=engine)
     assert_equal(expected, actual.unstack("space"))
 
+    actual = xarray_reduce(stacked.foo, "space", dim="z", func="sum", engine=engine)
+    assert_equal(expected.foo, actual.unstack("space"))
+
+    ds = xr.Dataset(
+        dict(a=(("z",), np.ones(10))),
+        coords=dict(b=(("z"), np.arange(2).repeat(5)), c=(("z"), np.arange(5).repeat(2))),
+    ).set_index(bc=["b", "c"])
+    expected = ds.groupby("bc").sum()
+    actual = xarray_reduce(ds, "bc", func="sum")
+    assert_equal(expected, actual)
+
 
 @pytest.mark.parametrize("chunks", (None, 2))
 def test_xarray_groupby_bins(chunks, engine):
@@ -400,3 +411,17 @@ def test_cache():
 
     xarray_reduce(ds, "labels", func="mean", method="blockwise")
     assert len(cache.data) == 2
+
+
+@pytest.mark.parametrize("use_cftime", [True, False])
+@pytest.mark.parametrize("func", ["count", "mean"])
+def test_datetime_array_reduce(use_cftime, func):
+
+    time = xr.DataArray(
+        xr.date_range("2009-01-01", "2012-12-31", use_cftime=use_cftime),
+        dims=("time",),
+        name="time",
+    )
+    expected = getattr(time.resample(time="YS"), func)()
+    actual = resample_reduce(time.resample(time="YS"), func=func, engine="flox")
+    assert_equal(expected, actual)
